@@ -24,16 +24,36 @@ class AdapterManager:
         self.__test_results = []
 
     @adapter_logger
-    def set_test_run_id(self, test_run_id: str):
+    def set_test_run_id(self, test_run_id: str) -> None:
         self.__config.set_test_run_id(test_run_id)
         self.__api_client.set_test_run_id(test_run_id)
 
     @adapter_logger
-    def get_test_run_id(self):
+    def get_test_run_id(self) -> str:
         if self.__config.get_mode() != AdapterMode.NEW_TEST_RUN:
-            return self.__config.get_test_run_id()
+            test_run_id = self.__config.get_test_run_id()
 
-        return self.__api_client.create_test_run()
+            self.__update_test_run_name(test_run_id)
+
+            return test_run_id
+
+        return self.__api_client.create_test_run(self.__config.get_test_run_name())
+
+    @adapter_logger
+    def __update_test_run_name(self, test_run_id: str) -> None:
+        test_run_name = self.__config.get_test_run_name()
+
+        if not test_run_name:
+            return
+
+        test_run = self.__api_client.get_test_run(test_run_id)
+
+        if test_run_name == test_run.name:
+            return
+
+        test_run.name = test_run_name
+
+        self.__api_client.update_test_run(test_run)
 
     @adapter_logger
     def get_autotests_for_launch(self):
@@ -43,7 +63,7 @@ class AdapterManager:
         return
 
     @adapter_logger
-    def write_test(self, test_result: TestResult):
+    def write_test(self, test_result: TestResult) -> None:
         if self.__config.should_import_realtime():
             self.__write_test_realtime(test_result)
 
@@ -52,14 +72,14 @@ class AdapterManager:
         self.__test_results.append(test_result)
 
     @adapter_logger
-    def __write_test_realtime(self, test_result: TestResult):
+    def __write_test_realtime(self, test_result: TestResult) -> None:
         test_result.set_automatic_creation_test_cases(
             self.__config.should_automatic_creation_test_cases())
 
         self.__test_result_map[test_result.get_external_id()] = self.__api_client.write_test(test_result)
 
     @adapter_logger
-    def write_tests(self):
+    def write_tests(self) -> None:
         if self.__config.should_import_realtime():
             self.__load_setup_and_teardown_step_results()
 
@@ -68,11 +88,11 @@ class AdapterManager:
         self.__write_tests_after_all()
 
     @adapter_logger
-    def __load_setup_and_teardown_step_results(self):
+    def __load_setup_and_teardown_step_results(self) -> None:
         self.__api_client.update_test_results(self.__fixture_manager.get_all_items(), self.__test_result_map)
 
     @adapter_logger
-    def __write_tests_after_all(self):
+    def __write_tests_after_all(self) -> None:
         fixtures = self.__fixture_manager.get_all_items()
 
         self.__api_client.write_tests(self.__test_results, fixtures)
